#!/usr/bin/env python
# coding: utf8

# Ce script est destiné à être utilisé conjointement avec le sketch Arduino "variateur.ino" fourni dans la même archive. 
# L'ensemble de ces deux programmes permet de faire varier la luminosité d'une LED à l'aide d'un curseur virtuel manipulé par la souris.
#
# © naute 2019 CC-BY-SA-NC


# Importation des biblothèques.

import wx
import serial
import time

# Instanciation et initialisation du port série.

portCom = serial.Serial()
portCom.port = '/dev/ttyACM0'
portCom.baudrate = 115200

# Dérivation d'une instance de la classe wx.Frame.

class FBase(wx.Frame): 
	def __init__(self, parent, title):
		wx.Frame.__init__(self, parent, title=title, size = (227,168))
		self.Show(True)	
		
		# Ouverture du port protégée par un bloc de gestion des exceptions : 
		# on teste ici un éventuel problème de liaison série.
		
		try:
			portCom.open()
		except serial.SerialException:
			dlg = wx.MessageDialog(self,"Vérifiez votre port série !\n\n Assurez vous que votre carte Arduino est bien connectée\n et que le port série attribué est bien 'ttyACM0.'", style = (wx.OK | wx.ICON_ERROR | wx.CENTER))
			dlg.ShowModal()
			dlg.Destroy()		
			self.Close()
		
		# Création des wxWidgets : ici, 1 bouton (wxButton)  et 1 curseur (wxSlider)		
					
		quitterBtn = wx.Button(self, wx.ID_EXIT, "Quitter", pos=(128, 96), size=(86, 31))								 	
		quitterBtn.SetBitmap(wx.Bitmap("quitter.png", wx.BITMAP_TYPE_PNG), wx.RIGHT)		
		curseur = wx.Slider(self, wx.ID_ANY, value = 0, minValue = 0, maxValue = 255, pos=(14, 5), size = (200, 40), style = (wx.SL_HORIZONTAL | wx.SL_VALUE_LABEL))		
		jauge = wx.Gauge(self, wx.ID_ANY, range = 255, pos = (14, 55), size = (200, 10), style = wx.GA_HORIZONTAL)
		affichage = wx.StaticText(self, wx.ID_ANY, label = "Valeur envoyée : 0", pos = (14, 75), size = (200, 30), style = 0)
				
		# Définition des gestionnaires d'évènement
			
		def onQuitterBtn(event):
			self.Close()	
			
		def onCurseurScroll(event):
			consigne = curseur.Value
			jauge.Value = consigne
			affichage.SetLabel("Valeur envoyée : " + str(consigne))
			portCom.write(str(consigne))
					
		# Connexion entre les commandes et leur gestionnaire d'évènement respectif	
		
		quitterBtn.Bind(wx.EVT_BUTTON, onQuitterBtn, quitterBtn)					
		curseur.Bind(wx.EVT_SCROLL, onCurseurScroll, curseur)
				
# Lancement de l'application

app = wx.App(False)
frame = FBase(None, "Variateur")
app.MainLoop()
